==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/DependenceGraph.h <==
// public class soot.jimple.toolkits.pointer.DependenceGraph

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4eaa70cb53c524 soot_jimple_toolkits_pointer_DependenceGraph

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_DependenceGraph_H_
#define _JC_soot_jimple_toolkits_pointer_DependenceGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_refs	_jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$refs	_jc_soot_jimple_toolkits_pointer_DependenceGraph$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceGraph$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object	_jc_soot_jimple_toolkits_pointer_DependenceGraph$object;

typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$fields_struct	_jc_soot_jimple_toolkits_pointer_DependenceGraph$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vmethods	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vtable	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vtype	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_soot_jimple_toolkits_pointer_DependenceGraph$fields_struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_DependenceGraph$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_DependenceGraph$method$addEdge$bba54b86a2c243b5(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, jshort, jshort);
extern jboolean _jc_soot_jimple_toolkits_pointer_DependenceGraph$method$areAdjacent$7d38a09b2c115d8b(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, jshort, jshort);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_DependenceGraph$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *);
extern _jc_byte_array *_jc_soot_jimple_toolkits_pointer_DependenceGraph$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *);
extern void _jc_soot_jimple_toolkits_pointer_DependenceGraph$method$setValue$ab2460f8c5636eee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, struct _jc_byte_array *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_DependenceGraph$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$addEdge$bba54b86a2c243b5;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$areAdjacent$7d38a09b2c115d8b;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$setValue$ab2460f8c5636eee;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vmethods {
	void	(*addEdge$bba54b86a2c243b5)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, jshort, jshort);
	jboolean	(*areAdjacent$7d38a09b2c115d8b)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, jshort, jshort);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *);
	void	(*setValue$ab2460f8c5636eee)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, struct _jc_byte_array *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vmethods	soot_jimple_toolkits_pointer_DependenceGraph;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_refs {
	struct _jc_java_util_HashSet$object	*edges;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$refs {
    _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_refs	soot_jimple_toolkits_pointer_DependenceGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_nonrefs	soot_jimple_toolkits_pointer_DependenceGraph;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object {
	_jc_soot_jimple_toolkits_pointer_DependenceGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_DependenceGraph$vtype _jc_soot_jimple_toolkits_pointer_DependenceGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_DependenceGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_DependenceGraph$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_DependenceGraph_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/DependenceGraph.h <==
// public class soot.jimple.toolkits.pointer.DependenceGraph

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4eaa70cb53c524 soot_jimple_toolkits_pointer_DependenceGraph

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_DependenceGraph_H_
#define _JC_soot_jimple_toolkits_pointer_DependenceGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_refs	_jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$refs	_jc_soot_jimple_toolkits_pointer_DependenceGraph$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceGraph$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object	_jc_soot_jimple_toolkits_pointer_DependenceGraph$object;

typedef struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$fields_struct	_jc_soot_jimple_toolkits_pointer_DependenceGraph$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vmethods	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vtable	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vtype	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_soot_jimple_toolkits_pointer_DependenceGraph$fields_struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_DependenceGraph$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_DependenceGraph$method$addEdge$bba54b86a2c243b5(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, jshort, jshort) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_pointer_DependenceGraph$method$areAdjacent$7d38a09b2c115d8b(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, jshort, jshort) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_DependenceGraph$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_jimple_toolkits_pointer_DependenceGraph$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_DependenceGraph$method$setValue$ab2460f8c5636eee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_DependenceGraph$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$addEdge$bba54b86a2c243b5;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$areAdjacent$7d38a09b2c115d8b;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$setValue$ab2460f8c5636eee;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceGraph$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vmethods {
	void	(*addEdge$bba54b86a2c243b5)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, jshort, jshort) _JC_JCNI_ATTR;
	jboolean	(*areAdjacent$7d38a09b2c115d8b)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, jshort, jshort) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *) _JC_JCNI_ATTR;
	void	(*setValue$ab2460f8c5636eee)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vmethods	soot_jimple_toolkits_pointer_DependenceGraph;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_refs {
	struct _jc_java_util_HashSet$object	*edges;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$refs {
    _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_refs	soot_jimple_toolkits_pointer_DependenceGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_DependenceGraph$sub_nonrefs	soot_jimple_toolkits_pointer_DependenceGraph;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_DependenceGraph$object {
	_jc_soot_jimple_toolkits_pointer_DependenceGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_DependenceGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_DependenceGraph$vtype _jc_soot_jimple_toolkits_pointer_DependenceGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_DependenceGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_DependenceGraph$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_DependenceGraph_H_ */
